@@ -67,6 +67,13 @@ def main():
         ,help="Install packages on user pip site repository."
     )
 
+    parser.add_argument(
+        '--target'
+        ,required=False
+        ,type=str
+        ,help="Specify where to place dependencies."
+    )
+
     parser.add_argument(
         '--debug'
         ,required=False
@@ -91,6 +98,7 @@ def main():
         ,upgrade=args.upgrade
         ,force=args.force
         ,user=args.user
+        ,target=args.target
         ,debug=args.debug
     ):
         parser.print_help()
\ No newline at end of file
